@@ -1,4 +1,5 @@
-from typing import List, Dict, Tuple, Union, Literal
+from typing import List, Dict, Tuple, Union
+from typing_extensions import Literal
 import numpy as np
 
 from fdsreader.utils import Surface, Mesh, Extent, Quantity, Dimension
@@ -245,7 +246,9 @@ class Obstruction:
                  rgba: Union[Tuple[()], Tuple[float, float, float, float]] = ()):
         self.id = oid
         self.side_surfaces = side_surfaces
-        self.bound_indices = bound_indices
+        self.bound_indices = {'x': (bound_indices[0], bound_indices[1]),
+                              'y': (bound_indices[2], bound_indices[3]),
+                              'z': (bound_indices[4], bound_indices[5])}
         self.color_index = color_index
         self.block_type = block_type
         self.texture_origin = texture_origin
@@ -253,7 +256,7 @@ class Obstruction:
             self.rgba = rgba
 
         self._extents: Dict[Mesh, Extent] = dict()
-        self.extent = tuple()
+        self.extent: Extent = tuple()
 
         self._boundary_data: Dict[int, Boundary] = dict()
 
@@ -286,11 +289,11 @@ class Obstruction:
     def get_boundary_data(self, quantity: Union[Quantity, str]):
         """Gets the boundary data for a specific quantity.
         """
-        if type(quantity) == str:
-            return next((x for x in self._boundary_data.values() if
-                         x.quantity.quantity.lower() == quantity.lower() or
-                         x.quantity.label.lower() == quantity.lower()), None)
-        return next((x for x in self._boundary_data.values() if x.quantity == quantity), None)
+        if type(quantity) != str:
+            quantity = quantity.quantity
+        return next((x for x in self._boundary_data.values() if
+                     x.quantity.quantity.lower() == quantity.lower() or
+                     x.quantity.label.lower() == quantity.lower()), None)
 
     @property
     def has_boundary_data(self):
