@@ -1,4 +1,4 @@
-from typing import Iterable, Union
+from typing import Iterable, Union, List
 
 from fdsreader.isof import Isosurface
 from fdsreader.utils.data import FDSDataCollection, Quantity
@@ -12,14 +12,13 @@ class IsosurfaceCollection(FDSDataCollection):
     def __init__(self, *isosurfaces: Iterable[Isosurface]):
         super().__init__(*isosurfaces)
 
-    def get_by_quantity(self, quantity: Union[str, Quantity]):
+    def filter_by_quantity(self, quantity: Union[str, Quantity]) -> List[Isosurface]:
+        """Get the isosurface for a specific quantity.
         """
-        """
-        if type(quantity) == str:
-            return next((x for x in self if
-                        x.quantity.quantity.lower() == quantity.lower() or
-                        x.quantity.label.lower() == quantity.lower()), None)
-        return next((x for x in self if x.quantity == quantity), None)
+        if type(quantity) != str:
+            quantity = quantity.quantity
+        return [x for x in self if x.quantity.quantity.lower() == quantity.lower() or
+                x.quantity.label.lower() == quantity.lower()]
 
     def __repr__(self):
         return "IsosurfaceCollection(" + super(IsosurfaceCollection, self).__repr__() + ")"
