@@ -6,6 +6,7 @@ import numpy as np
 import pickle
 
 from fdsreader.bndf import Obstruction, Patch
+from fdsreader.bndf.ObstructionCollection import ObstructionCollection
 from fdsreader.isof import Isosurface
 from fdsreader.isof.IsosurfaceCollection import IsosurfaceCollection
 from fdsreader.part import Particle
@@ -33,9 +34,9 @@ class Simulation:
     :ivar out_file_path: Path to the .out file of the simulation.
     :ivar surfaces: List containing all surfaces defined in this simulation.
     :ivar meshes: List containing all meshes (grids) defined in this simulation.
-    :ivar obstructions: List containing all obstructions defined in this simulation.
     :ivar ventilations: List containing all ventilations defined in this simulation.
-    :ivar slices: All defined slices combined into a :class:`ParticleCollection`.
+    :ivar obstructions: All defined obstructions combined into a :class:`ObstructionCollection`.
+    :ivar slices: All defined slices combined into a :class:`SliceCollection`.
     :ivar data_3d: All defined 3D plotting data combined into a :class:`Plot3DCollection`.
     :ivar isosurfaces: All defined isosurfaces combined into a :class:`IsosurfaceCollection`.
     :ivar particles: All defined particles combined into a :class:`ParticleCollection`.
@@ -154,14 +155,14 @@ class Simulation:
             # POST INIT (post read)
             self.out_file_path = os.path.join(self.root_path, self.chid + ".out")
             self.ventilations: List[Ventilation] = list(self.ventilations.values())
-            self.obstructions: List[Obstruction] = list(self.obstructions.values())
+            self.obstructions = ObstructionCollection(self.obstructions.values())
             for obst in self.obstructions:
                 obst._post_init()
             # Combine the gathered temporary information into data collections
             self.slices = SliceCollection(
-                Slice(self.root_path, slice_data[0]["cell_centered"], slice_data[0]["times"],
-                      slice_data[1:]) for slice_data
-                in self.slices.values())
+                Slice(self.root_path, slice_data[0]["id"], slice_data[0]["cell_centered"],
+                      slice_data[0]["times"], slice_data[1:]) for slice_data in
+                self.slices.values())
             self.data_3d = Plot3DCollection(self.data_3d.keys(), self.data_3d.values())
             self.isosurfaces = IsosurfaceCollection(self.isosurfaces.values())
             if self.particles is None:
@@ -220,8 +221,6 @@ class Simulation:
         assert smv_file.readline().strip() == "VENT"
         self._load_vents(smv_file, mesh)
 
-        # TODO: Offset und closed/open vents
-
         return mesh
 
     def _load_obstructions(self, smv_file: TextIO, mesh: Mesh):
@@ -241,8 +240,9 @@ class Simulation:
 
         for tmp in temp_data:
             line = smv_file.readline().strip().split()
-            bound_indices = (int(float(line[0])), int(float(line[1])), int(float(line[2])),
-                             int(float(line[3])), int(float(line[4])), int(float(line[5])))
+            bound_indices = (
+            int(float(line[0])) - 1, int(float(line[1])) - 1, int(float(line[2])) - 1,
+            int(float(line[3])) - 1, int(float(line[4])) - 1, int(float(line[5])) - 1)
             color_index = int(line[6])
             block_type = int(line[7])
             if color_index == -3:
@@ -359,7 +359,9 @@ class Simulation:
         else:
             cell_centered = False
 
-        slice_id = int(line.split('!')[1].strip().split()[0])
+        slice_index = int(line.split('!')[1].strip().split()[0])
+
+        slice_id = line.split('%')[1].split('&')[0].strip() if '%' in line else ""
 
         mesh_index = int(line.split('&')[0].strip().split()[1]) - 1
         mesh = self.meshes[mesh_index]
@@ -381,13 +383,14 @@ class Simulation:
                 times.append(float(line.split()[0]))
         times = np.array(times)
 
-        if slice_id not in self.slices:
-            self.slices[slice_id] = [{"cell_centered": cell_centered, "times": times}]
-        self.slices[slice_id].append(
+        if slice_index not in self.slices:
+            self.slices[slice_index] = [
+                {"cell_centered": cell_centered, "times": times, "id": slice_id}]
+        self.slices[slice_index].append(
             {"dimension": dimension, "extent": extent, "mesh": mesh, "filename": filename,
              "quantity": quantity, "label": label, "unit": unit})
 
-        logging.debug("Found SLICE with id: :i", slice_id)
+        logging.debug("Found SLICE with id: :i", slice_index)
 
     def _load_boundary_data(self, smv_file: TextIO, line: str):
         """Loads the boundary data at current pointer position.
