@@ -1,10 +1,10 @@
-from __future__ import annotations
 import os
 from copy import deepcopy
 
 import numpy as np
 import logging
-from typing import Dict, Collection, Tuple, Literal
+from typing import Dict, Collection, Tuple
+from typing_extensions import Literal
 
 from fdsreader.utils import Dimension, Quantity, Mesh, Extent
 from fdsreader import settings
@@ -34,7 +34,7 @@ class SubSlice:
 
     _offset = 3 * fdtype.new((('c', 30),)).itemsize + fdtype.new((('i', 6),)).itemsize
 
-    def __init__(self, parent_slice: Slice, filename: str, dimension: Dimension, extent: Extent,
+    def __init__(self, parent_slice, filename: str, dimension: Dimension, extent: Extent,
                  mesh: Mesh, has_vector_data: bool):
         self.mesh = mesh
         self.dimension = dimension
@@ -67,7 +67,7 @@ class SubSlice:
 
     @property
     def data(self) -> np.ndarray:
-        """Method to lazy load the slice's data for a specific quantity.
+        """Method to lazy load the slice's data.
         """
         if not hasattr(self, "_data"):
             n_t = self.parent_slice.times.shape[0]
@@ -79,14 +79,14 @@ class SubSlice:
 
     @property
     def vector_data(self) -> Dict[str, np.ndarray]:
-        """Method to lazy load the slice's vector data for a specific quantity if it exists.
+        """Method to lazy load the slice's vector data if it exists.
         """
         if not hasattr(self, "_vector_data"):
             raise AttributeError("There is no vector data available for this slice.")
         if len(self._vector_data) == 0:
             n_t = self.parent_slice.times.shape[0]
 
-            for direction in ('u', 'v', 'w'):
+            for direction in self.vector_filenames.keys():
                 file_path = os.path.join(self.parent_slice.root_path,
                                          self.vector_filenames[direction])
                 self._vector_data[direction] = np.empty((n_t,) + self.shape, dtype=np.float32)
@@ -118,13 +118,15 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
     :ivar extent: :class:`Extent` object containing 3-dimensional extent information.
     """
 
-    def __init__(self, root_path: str, cell_centered: bool, times: np.ndarray,
+    def __init__(self, root_path: str, slice_id: str, cell_centered: bool, times: np.ndarray,
                  multimesh_data: Collection[Dict]):
         self.root_path = root_path
         self.cell_centered = cell_centered
 
         self.times = times
 
+        self.id = slice_id
+
         # List of all subslices this slice consists of (one per mesh).
         self._subslices: Dict[Mesh, SubSlice] = dict()
 
@@ -146,9 +148,12 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
                 vector_temp[mesh_data["mesh"]][mesh_data["quantity"]] = mesh_data["filename"]
 
         for mesh, vector_filenames in vector_temp.items():
-            self._subslices[mesh].vector_filenames["u"] = vector_filenames["U-VELOCITY"]
-            self._subslices[mesh].vector_filenames["v"] = vector_filenames["V-VELOCITY"]
-            self._subslices[mesh].vector_filenames["w"] = vector_filenames["W-VELOCITY"]
+            if "U-VELOCITY" in vector_filenames:
+                self._subslices[mesh].vector_filenames["u"] = vector_filenames["U-VELOCITY"]
+            if "V-VELOCITY" in vector_filenames:
+                self._subslices[mesh].vector_filenames["v"] = vector_filenames["V-VELOCITY"]
+            if "W-VELOCITY" in vector_filenames:
+                self._subslices[mesh].vector_filenames["w"] = vector_filenames["W-VELOCITY"]
 
         vals = self._subslices.values()
         self.extent = Extent(min(vals, key=lambda e: e.extent.x_start).extent.x_start,
@@ -178,18 +183,19 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         return self._subslices[mesh]
 
     @property
-    def extent_dirs(self) -> Tuple[Literal['x', 'y', 'z'], Literal['x', 'y', 'z']]:
+    def extent_dirs(self) -> Tuple[
+        Literal['x', 'y', 'z'], Literal['x', 'y', 'z'], Literal['x', 'y', 'z']]:
         """The directions in which there is an extent. All three dimensions in case the slice is 3D.
         """
         ior = self.orientation
         if ior == 0:
-            return ('x', 'y', 'z')
+            return 'x', 'y', 'z'
         elif ior == 1:
-            return ('y', 'z')
+            return 'y', 'z'
         elif ior == 2:
-            return ('x', 'z')
+            return 'x', 'z'
         else:
-            return ('x', 'y')
+            return 'x', 'y'
 
     def clear_cache(self):
         """Remove all data from the internal cache that has been loaded so far to free memory.
